<?php
/**
 * Product data parallel structure for storing product properties.
 *
 * @package  WooCommerce Free Gift Coupons/Product Data
 * @since    3.7.0
 * @version  3.7.0
 */

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * WC_FGC_Product_Data class
 */
class WC_FGC_Product_Data {

	/**
	 * Use WeakMap to store product data.
	 *
	 * @var bool
	 */
	private $use_weakmap = false;

	/**
	 * Product data.
	 *
	 * @var array
	 */
	private $data = array();

	//use WC_FGC_Singleton;

	/**
	 * Overriding the constructor with a private one prevents calling it directly.
	 */
	public function __construct() {
		$this->use_weakmap = defined( 'PHP_VERSION_ID' ) && PHP_VERSION_ID >= 80000;

		if ( $this->use_weakmap ) {
			$this->data = new WeakMap(); // phpcs:ignore PHPCompatibility.Classes.NewClasses
		}
	}

	/**
	 * Gets product data.
	 *
	 * @param WC_Product   $product
	 * @param string       $key
	 * @param null|string  $default
	 *
	 * @return string
	 */
	public function get( $product, $key, $default = null ) {

		if ( ! is_object( $product ) || ! method_exists( $product, 'get_id' ) ) {
			return $default;
		}

		$identifier = $this->use_weakmap ? $product : spl_object_hash( $product ) . $product->get_id();

		if ( isset( $this->data[ $identifier ] ) && isset( $this->data[ $identifier ][ $key ] ) ) {
			$value = $this->data[ $identifier ][ $key ];
        } else {
			$value = $default;
		}

		return $value;

	}

	/**
	 * Sets product data.
	 *
	 * @param WC_Product  $product
	 * @param string      $key
	 * @param string      $value
	 *
	 */
	public function set( $product, $key, $value ) {

		if ( ! is_object( $product ) || ! method_exists( $product, 'get_id' ) ) {
			return;
		}

		$identifier = $this->use_weakmap ? $product : spl_object_hash( $product ) . $product->get_id();

		if ( ! isset( $this->data[ $identifier ] ) ) {
			$this->data[ $identifier ] = array();
		}

		$this->data[ $identifier ][ $key ] = $value;
	


	}

} // End class.
